==> huaweicloudsdkdns-3.0.47-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/values_item.py <==
# coding: utf-8

import pprint
import re

import six





class ValuesItem:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'values': 'list[ListApiVersionsItem]'
    }

    attribute_map = {
        'values': 'values'
    }

    def __init__(self, values=None):
        """ValuesItem - a model defined in huaweicloud sdk"""
        
        

        self._values = None
        self.discriminator = None

        if values is not None:
            self.values = values

    @property
    def values(self):
        """Gets the values of this ValuesItem.

        所有版本列表。

        :return: The values of this ValuesItem.
        :rtype: list[ListApiVersionsItem]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ValuesItem.

        所有版本列表。

        :param values: The values of this ValuesItem.
        :type: list[ListApiVersionsItem]
        """
        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValuesItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdns-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdns/v2/model/values_item.py <==
# coding: utf-8

import re
import six





class ValuesItem:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'values': 'list[ListApiVersionsItem]'
    }

    attribute_map = {
        'values': 'values'
    }

    def __init__(self, values=None):
        """ValuesItem - a model defined in huaweicloud sdk"""
        
        

        self._values = None
        self.discriminator = None

        if values is not None:
            self.values = values

    @property
    def values(self):
        """Gets the values of this ValuesItem.

        所有版本列表。

        :return: The values of this ValuesItem.
        :rtype: list[ListApiVersionsItem]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this ValuesItem.

        所有版本列表。

        :param values: The values of this ValuesItem.
        :type: list[ListApiVersionsItem]
        """
        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValuesItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
